package com.jeffknecht.dynadao.api;

import java.sql.ResultSet;
import java.sql.SQLException;

/**
 * Provides the ability to override the default behavior and map a value 
 * in the resultset to any arbitrary value.  Classes that implement
 * this interface can be set as the columnMapper value on a 
 * Column annotation.
 * 
 * In addition to implementing this interface, ColumnMapper implementations
 * must provide a default constructor and must be thread-safe.
 * 
 * @author jeff.knecht
 */
public interface ColumnMapper {

	/**
	 * Returns the value derived from the current row in the resultset
	 * in the column specified by columnName.
	 * 
	 * @param rs
	 * @param columnName
	 * @return
	 * @throws SQLException
	 */
	public Object mapValue(ResultSet rs, String columnName) throws SQLException;

}
