package com.jeffknecht.dynadao.api;

import java.lang.reflect.Field;

/**
 * <p>When a column is tagged with a generator
 * class, the implementation of this interface
 * is responsible for generating a value for that
 * field.</p>
 * 
 * <p>In addition to implementing the methods defined
 * in this interface, the implementation
 * must provide a default constructor and must be thread-safe.</p>
 * 
 * @author jeff.knecht
 *
 */
public interface Generator {
	
	/**
	 * Indicates what kind of operation is currently being performed.
	 * 
	 * @author jeff.knecht
	 */
	public static enum Operation {
		INSERT,
		UPDATE
	}
	
	/**
	 * Implementers of this method must generate
	 * and set a value on the supplied field
	 * in the target object.
	 *  
	 * @param field The field whose value should be set
	 * @param target The object on which to set the value
	 * @param operation Indicates whether the operation is an insert or an update
	 */
	public void generateValue(Field field, Object target, Operation operation) throws IllegalAccessException;
}
